@@ -9,8 +9,8 @@ import subprocess
 
 # cli_commands for the buildpan 
 
-from c_commands import init
-from c_commands import version
+from cli_commands import init
+from cli_commands import version
 
 @click.group(help="CLI tool to manage CI- CD of projects")
 def buildpan():
